==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: th\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "ส่วนหลัง"

, "Standard IMAP"
: "IMAP มาตรฐาน"

, "Standard SMTP"
: "SMTP มาตรฐาน "

, "Imap"
: ""

, "Hostname"
: "ชื่อแม่ข่าย"

, "Username"
: "ชื่อผู้ใช้"

, "Password"
: "รหัสผ่าน"

, "Port"
: "พอร์ท"

, "Secure Connection"
: "การเชื่อมต่อที่ปลอดภัย"

, "None"
: "ไม่มีเลย"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "ใช้บัญชีของระบบ"

, "No"
: "ไม่"

, "Yes"
: "ใช่"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "การอนุญาต"

, "Login"
: "ลงบันทึกเข้า"

, "Plain"
: "ธรรมดา"

, "Primary Domain"
: "โดเมนหลัก"

, "Secondary Domains (comma separated)"
: "โดเมนรอง (แบ่งโดยจุลภาค)"

, "Notifications service address"
: ""

, "Notification Username"
: "การแจ้งชื่อผู้ใช้"

, "Notification Password"
: "การแจ้งรหัสผ่าน"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: "กรอง"

, "MySql Hostname"
: "ชื่อแม่ข่าย MySql"

, "MySql Database"
: "ฐานข้อมูล MySql"

, "MySql User"
: "ผู้ใช้ MySql"

, "MySql Password"
: "รหัสผ่าน MySql"

, "MySql Port"
: "พอร์ท MySql"

, "User or UID"
: "ผู้ใช้ หรือ UID"

, "Group or GID"
: "กลุ่ม หรือ GID"

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: "ข้อตกลงเรื่องความเป็นส่วนตัว"

, "Accept Terms and Conditions"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "ตรวจสอบ"

, "Result"
: "ผลลัพธ์"

, "Error"
: "ผิดพลาด"

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Install application"
: "ติดตั้งแอพพลิเคชั่น"

, "File"
: "ไฟล์"

, "Setup Authentication"
: "การอนุญาตติดตั้ง"

, "Database"
: "ฐานข้อมูล"

, "User"
: "ผู้ใช้"

, "Prefix"
: ""

, "Logging"
: ""

, "Filename"
: "ชื่อไฟล์"

, "Priority"
: "ลำดับความสำคัญ"

, "Caching"
: "กำลังแคช"

, "Lifetime (seconds)"
: "เวลาชีวิต (วินาที)"

, "Path"
: "เส้นทาง"

, "Queue"
: "คิว"

, "Session"
: "เซสชัน"

, "Temporary files"
: "ไฟล์ชั่วคราว"

, "Temporary Files Path"
: "ทางของไฟล์ชั่วคราว"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: "ไม่สามารถใช้งานได้"

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Save config"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: "อีเมล"

, "Application Manager"
: "ตัวจัดการแอพพลิเคชั่น"

, "Delete all existing users and groups"
: "ลบผ๔้ใช้และกลุ่มที่มีอยู่ทั้งหมด"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "การสลับจาก SQL ไปยัง LDAP จะลบบัญชี กลุ่ม และหน้าที่ของผู้ใช้ที่มีอยู่ทั้งหมด คุณแน่ใจว่าต้องการสลับการจัดเก็บบัญชีส่วนหลังไปใช้ LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: "การยืนยันรหัสผ่าน"

, "Authentication provider"
: "ผู้ให้การอนุญาต"

, "Try to split username"
: "พยายามที่จะแตกชื่อผู้ใช้"

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: "แม่ข่าย"

, "Login name"
: "ชื่อที่เข้าใช้"

, "Bind requires DN"
: "การเชื่อมต่อต้องการ DN"

, "Start TLS"
: "เริ่ม TLS"

, "Base DN"
: "ฐาน DN"

, "Search filter"
: "หาตัวกรอง"

, "Certificate validation"
: ""

, "CA file"
: "ไฟล์ CA"

, "CRL directory"
: "ไดเรคทอรี่ CRL "

, "Accounts storage"
: "การจัดเก็บบัญชี"

, "Default user group name"
: "ชื่อกลุ่มผู้ใช้หลัก"

, "Default admin group name"
: "ชื่อกลุ่มผู้ดูแลหลัก"

, "Login panel"
: "ช่องลงชื่อเข้าใช้"

, "Reuse last username logged"
: ""

, "Password Settings"
: "การรติดตั้งรหัสผ่าน"

, "User can change password"
: "ผู้ใช้สามารถเปลี่ยนรหัสผ่านได้"

, "Enable password policy"
: ""

, "Only ASCII"
: "เฉพาะ ASCII"

, "Minimum length"
: "ความยาวอย่างน้อยที่สุด"

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: "จำนวนหมายเลขที่น้อยที่สุด"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: "ว่าง"

, "User DN"
: " ผู้ใช้ DN"

, "User Filter"
: "ตัวกรองผู้ใช้"

, "User Search Scope"
: "ขอบเขตการค้นหาของผู้ใช้"

, "Groups DN"
: "กลุ่ม DN"

, "Group Filter"
: "ตัวกรองกลุ่ม"

, "Group Search Scope"
: "ขอบเขตการค้นหาของกลุ่ม"

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "รหัสของผู้ใช้ที่สั้นที่สุด"

, "Max User Id"
: "รหัสของผู้ใช้ที่ยาวที่สุด"

, "Min Group Id"
: "รหัสของกลุ่มที่สั้นที่สุด"

, "Max Group Id"
: "รหัสของกลุ่มที่ยาวที่สุด"

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Passwords don't match"
: "รหัสผ่านไม่ตรง"

, "Should not be empty"
: "ไม่ควรว่างไว้"

, "Setup"
: ""

, "Application, Applications"
: [
  "แอพพลิเคชั่น"

]
, "Name"
: "ชื่อ"

, "Enabled"
: "เปิดใช้งานแล้ว"

, "Order"
: "คำสั่ง"

, "Installed Version"
: "เวอร์ชั่นที่ได้ติดตั้ง"

, "Available Version"
: "เวอร์ชั่นที่มี"

, "Status"
: "สถานะ"

, "Depends on"
: "ขึ้นอยู่กับ"

, "Uninstall application"
: "ถอนการติดตั้งแอพพลิเคชั่น"

, "Update application"
: "อัพเดทแอพพลิเคชั่น"

, "Go to {0} login"
: "ไปยังการเข้าใช้ {0} "

, "uninstall"
: "ถอนการติดตั้ง"

, "Do you really want to uninstall the application(s)?"
: "คุณแน่ใจว่าต้องการถอนการติดตั้งแอพพลิเคชั่น(s)?"

, "This may take a while"
: "นี่อาจจะใช้เวลาสักครู่"

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Application"
: "แอพพลิเคชั่น"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-th-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: "ข้อตกลงเรื่องความเป็นส่วนตัว"

, "Accept Terms and Conditions"
: ""

, "Backend"
: "ส่วนหลัง"

, "Standard IMAP"
: "IMAP มาตรฐาน"

, "Standard SMTP"
: "SMTP มาตรฐาน "

, "Imap"
: ""

, "Hostname"
: "ชื่อแม่ข่าย"

, "Username"
: "ชื่อผู้ใช้"

, "Password"
: "รหัสผ่าน"

, "Port"
: "พอร์ท"

, "Secure Connection"
: "การเชื่อมต่อที่ปลอดภัย"

, "None"
: "ไม่มีเลย"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "ใช้บัญชีของระบบ"

, "No"
: "ไม่"

, "Yes"
: "ใช่"

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "การอนุญาต"

, "Login"
: "ลงบันทึกเข้า"

, "Plain"
: "ธรรมดา"

, "Primary Domain"
: "โดเมนหลัก"

, "Secondary Domains (comma separated)"
: "โดเมนรอง (แบ่งโดยจุลภาค)"

, "Notifications service address"
: ""

, "Notification Username"
: "การแจ้งชื่อผู้ใช้"

, "Notification Password"
: "การแจ้งรหัสผ่าน"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: "กรอง"

, "MySql Hostname"
: "ชื่อแม่ข่าย MySql"

, "MySql Database"
: "ฐานข้อมูล MySql"

, "MySql User"
: "ผู้ใช้ MySql"

, "MySql Password"
: "รหัสผ่าน MySql"

, "MySql Port"
: "พอร์ท MySql"

, "User or UID"
: "ผู้ใช้ หรือ UID"

, "Group or GID"
: "กลุ่ม หรือ GID"

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: ""

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: "อีเมล"

, "Application Manager"
: "ตัวจัดการแอพพลิเคชั่น"

, "Setup"
: ""

, "Name"
: "ชื่อ"

, "Enabled"
: "เปิดใช้งานแล้ว"

, "Order"
: "คำสั่ง"

, "Installed Version"
: "เวอร์ชั่นที่ได้ติดตั้ง"

, "Available Version"
: "เวอร์ชั่นที่มี"

, "Status"
: "สถานะ"

, "Depends on"
: "ขึ้นอยู่กับ"

, "Install application"
: "ติดตั้งแอพพลิเคชั่น"

, "Uninstall application"
: "ถอนการติดตั้งแอพพลิเคชั่น"

, "Update application"
: "อัพเดทแอพพลิเคชั่น"

, "Go to {0} login"
: "ไปยังการเข้าใช้ {0} "

, "uninstall"
: "ถอนการติดตั้ง"

, "Do you really want to uninstall the application(s)?"
: "คุณแน่ใจว่าต้องการถอนการติดตั้งแอพพลิเคชั่น(s)?"

, "This may take a while"
: "นี่อาจจะใช้เวลาสักครู่"

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "ลบผ๔้ใช้และกลุ่มที่มีอยู่ทั้งหมด"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "การสลับจาก SQL ไปยัง LDAP จะลบบัญชี กลุ่ม และหน้าที่ของผู้ใช้ที่มีอยู่ทั้งหมด คุณแน่ใจว่าต้องการสลับการจัดเก็บบัญชีส่วนหลังไปใช้ LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: "การยืนยันรหัสผ่าน"

, "Authentication provider"
: "ผู้ให้การอนุญาต"

, "Try to split username"
: "พยายามที่จะแตกชื่อผู้ใช้"

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: "แม่ข่าย"

, "Login name"
: "ชื่อที่เข้าใช้"

, "Bind requires DN"
: "การเชื่อมต่อต้องการ DN"

, "Start TLS"
: "เริ่ม TLS"

, "Base DN"
: "ฐาน DN"

, "Search filter"
: "หาตัวกรอง"

, "Certificate validation"
: ""

, "CA file"
: "ไฟล์ CA"

, "CRL directory"
: "ไดเรคทอรี่ CRL "

, "Accounts storage"
: "การจัดเก็บบัญชี"

, "Default user group name"
: "ชื่อกลุ่มผู้ใช้หลัก"

, "Default admin group name"
: "ชื่อกลุ่มผู้ดูแลหลัก"

, "Login panel"
: "ช่องลงชื่อเข้าใช้"

, "Reuse last username logged"
: ""

, "Password Settings"
: "การรติดตั้งรหัสผ่าน"

, "User can change password"
: "ผู้ใช้สามารถเปลี่ยนรหัสผ่านได้"

, "Enable password policy"
: ""

, "Only ASCII"
: "เฉพาะ ASCII"

, "Minimum length"
: "ความยาวอย่างน้อยที่สุด"

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: "จำนวนหมายเลขที่น้อยที่สุด"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: "ว่าง"

, "User DN"
: " ผู้ใช้ DN"

, "User Filter"
: "ตัวกรองผู้ใช้"

, "User Search Scope"
: "ขอบเขตการค้นหาของผู้ใช้"

, "Groups DN"
: "กลุ่ม DN"

, "Group Filter"
: "ตัวกรองกลุ่ม"

, "Group Search Scope"
: "ขอบเขตการค้นหาของกลุ่ม"

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "รหัสของผู้ใช้ที่สั้นที่สุด"

, "Max User Id"
: "รหัสของผู้ใช้ที่ยาวที่สุด"

, "Min Group Id"
: "รหัสของกลุ่มที่สั้นที่สุด"

, "Max Group Id"
: "รหัสของกลุ่มที่ยาวที่สุด"

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: ""

, "Passwords don't match"
: "รหัสผ่านไม่ตรง"

, "Should not be empty"
: "ไม่ควรว่างไว้"

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "ตรวจสอบ"

, "Result"
: "ผลลัพธ์"

, "Error"
: "ผิดพลาด"

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Application, Applications"
: [
  "แอพพลิเคชั่น"

]
, "File"
: "ไฟล์"

, "Setup Authentication"
: "การอนุญาตติดตั้ง"

, "Database"
: "ฐานข้อมูล"

, "User"
: "ผู้ใช้"

, "Prefix"
: ""

, "Logging"
: ""

, "Filename"
: "ชื่อไฟล์"

, "Priority"
: "ลำดับความสำคัญ"

, "Caching"
: "กำลังแคช"

, "Lifetime (seconds)"
: "เวลาชีวิต (วินาที)"

, "Path"
: "เส้นทาง"

, "Queue"
: "คิว"

, "Session"
: "เซสชัน"

, "Temporary files"
: "ไฟล์ชั่วคราว"

, "Temporary Files Path"
: "ทางของไฟล์ชั่วคราว"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: "ไม่สามารถใช้งานได้"

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "แอพพลิเคชั่น"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
